/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "3.0.4"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 2

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Substitute the type names.  */
#define YYSTYPE         CONF_STYPE
/* Substitute the variable and function names.  */
#define yyparse         conf_parse
#define yylex           conf_lex
#define yyerror         conf_error
#define yydebug         conf_debug
#define yynerrs         conf_nerrs


/* Copy the first part of user declarations.  */
#line 54 "parser/confFile.y" /* yacc.c:339  */
  
#include "mediatex-config.h"
  /* yyscan_t is pre-defined by mediatex-config.h and will be defined
     by Flex header bellow */

#line 79 "parser/confFile.tab.c" /* yacc.c:339  */

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 1
#endif

/* In a future release of Bison, this section will be replaced
   by #include "confFile.tab.h".  */
#ifndef YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
# define YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef CONF_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define CONF_DEBUG 1
#  else
#   define CONF_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define CONF_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined CONF_DEBUG */
#if CONF_DEBUG
extern int conf_debug;
#endif

/* Token type.  */
#ifndef CONF_TOKENTYPE
# define CONF_TOKENTYPE
  enum conf_tokentype
  {
    confERROR = 258,
    confHOST = 259,
    confNETWORKS = 260,
    confGATEWAYS = 261,
    confMDTXPORT = 262,
    confSSHPORT = 263,
    confHTTPPORT = 264,
    confHTTPSPORT = 265,
    confCACHESIZE = 266,
    confCACHETTL = 267,
    confQUERYTTL = 268,
    confCHECKTTL = 269,
    confFILETTL = 270,
    confSUPPTTL = 271,
    confMAXSCORE = 272,
    confBADSCORE = 273,
    confPOWSUPP = 274,
    confFACTSUPP = 275,
    confCOLL = 276,
    confCOMMENT = 277,
    confSHARE = 278,
    confLOCALHOST = 279,
    confCOMMA = 280,
    confDOT = 281,
    confCOLON = 282,
    confAROBASE = 283,
    confMINUS = 284,
    confENDBLOCK = 285,
    confMOTDPOLICY = 286,
    confSTRING = 287,
    confNUMBER = 288,
    confSCORE = 289,
    confSIZE = 290,
    confTIME = 291
  };
#endif
/* Tokens.  */
#define confERROR 258
#define confHOST 259
#define confNETWORKS 260
#define confGATEWAYS 261
#define confMDTXPORT 262
#define confSSHPORT 263
#define confHTTPPORT 264
#define confHTTPSPORT 265
#define confCACHESIZE 266
#define confCACHETTL 267
#define confQUERYTTL 268
#define confCHECKTTL 269
#define confFILETTL 270
#define confSUPPTTL 271
#define confMAXSCORE 272
#define confBADSCORE 273
#define confPOWSUPP 274
#define confFACTSUPP 275
#define confCOLL 276
#define confCOMMENT 277
#define confSHARE 278
#define confLOCALHOST 279
#define confCOMMA 280
#define confDOT 281
#define confCOLON 282
#define confAROBASE 283
#define confMINUS 284
#define confENDBLOCK 285
#define confMOTDPOLICY 286
#define confSTRING 287
#define confNUMBER 288
#define confSCORE 289
#define confSIZE 290
#define confTIME 291

/* Value type.  */
#if ! defined CONF_STYPE && ! defined CONF_STYPE_IS_DECLARED

union CONF_STYPE
{
#line 60 "parser/confFile.y" /* yacc.c:355  */

  char          string[MAX_SIZE_STRING+1];
  unsigned int  number;
  float         score;
  off_t         size;
  time_t        time;

#line 207 "parser/confFile.tab.c" /* yacc.c:355  */
};

typedef union CONF_STYPE CONF_STYPE;
# define CONF_STYPE_IS_TRIVIAL 1
# define CONF_STYPE_IS_DECLARED 1
#endif



int conf_parse (yyscan_t yyscanner, Collection* coll);
/* "%code provides" blocks.  */
#line 26 "parser/confFile.y" /* yacc.c:355  */

/*=======================================================================
 * Version: this file is generated by BISON using confFile.y
 * Project: MediaTeX
 * Module : conf parser
 *
 * configuation file parser

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE CONF_STYPE

#line 247 "parser/confFile.tab.c" /* yacc.c:355  */

#endif /* !YY_CONF_PARSER_CONFFILE_TAB_H_INCLUDED  */

/* Copy the second part of user declarations.  */
#line 68 "parser/confFile.y" /* yacc.c:358  */

  // upper YYSTYPE union is required by Flex headers
#include "parser/confFile.h"

#define LINENO conf_get_lineno(yyscanner)
  
void conf_error(yyscan_t yyscanner, Collection* coll, 
		const char* message);

#line 262 "parser/confFile.tab.c" /* yacc.c:358  */

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef YY_ATTRIBUTE
# if (defined __GNUC__                                               \
      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
# else
#  define YY_ATTRIBUTE(Spec) /* empty */
# endif
#endif

#ifndef YY_ATTRIBUTE_PURE
# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
#endif

#if !defined _Noreturn \
     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
# if defined _MSC_VER && 1200 <= _MSC_VER
#  define _Noreturn __declspec (noreturn)
# else
#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif

#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
    _Pragma ("GCC diagnostic push") \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif


#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined CONF_STYPE_IS_TRIVIAL && CONF_STYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYSIZE_T yynewbytes;                                            \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / sizeof (*yyptr);                          \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  49
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   132

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  37
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  17
/* YYNRULES -- Number of rules.  */
#define YYNRULES  51
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  103

/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
   by yylex, with out-of-bounds checking.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   291

#define YYTRANSLATE(YYX)                                                \
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, without out-of-bounds checking.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36
};

#if CONF_DEBUG
  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   130,   130,   131,   132,   133,   136,   144,   157,   158,
     161,   162,   167,   168,   169,   174,   179,   184,   191,   192,
     195,   204,   209,   213,   217,   223,   228,   233,   238,   243,
     248,   253,   258,   263,   268,   273,   278,   283,   288,   293,
     301,   302,   305,   306,   309,   310,   313,   314,   317,   324,
     331,   338
};
#endif

#if CONF_DEBUG || YYERROR_VERBOSE || 1
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "confERROR", "confHOST", "confNETWORKS",
  "confGATEWAYS", "confMDTXPORT", "confSSHPORT", "confHTTPPORT",
  "confHTTPSPORT", "confCACHESIZE", "confCACHETTL", "confQUERYTTL",
  "confCHECKTTL", "confFILETTL", "confSUPPTTL", "confMAXSCORE",
  "confBADSCORE", "confPOWSUPP", "confFACTSUPP", "confCOLL", "confCOMMENT",
  "confSHARE", "confLOCALHOST", "confCOMMA", "confDOT", "confCOLON",
  "confAROBASE", "confMINUS", "confENDBLOCK", "confMOTDPOLICY",
  "confSTRING", "confNUMBER", "confSCORE", "confSIZE", "confTIME",
  "$accept", "stanzas", "collectionStanza", "collection",
  "collectionLines", "collectionLine", "supports", "support", "confLine",
  "cnetworks", "cgateways", "Cnetworks", "Cgateways", "cnetwork",
  "cgateway", "Cnetwork", "Cgateway", YY_NULLPTR
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[NUM] -- (External) token number corresponding to the
   (internal) symbol number NUM (which must be that of a token).  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291
};
# endif

#define YYPACT_NINF -32

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-32)))

#define YYTABLE_NINF -1

#define yytable_value_is_error(Yytable_value) \
  0

  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
     STATE-NUM.  */
static const yytype_int8 yypact[] =
{
      28,   -31,   -30,   -29,   -10,    -9,    -8,    -7,    -6,    -5,
      -4,    -3,    18,    19,    22,    32,    33,    34,    21,    37,
      38,     0,   -32,    52,   -32,   -32,   -32,    45,   -32,   -32,
      53,   -32,   -32,   -32,   -32,   -32,    39,    41,    46,    48,
      50,    51,   -32,   -32,   -32,   -32,    56,   -32,   -32,   -32,
     -32,   -32,    57,    58,    55,    59,    60,    62,    63,    64,
      49,   -32,   -30,   -29,   -32,   -32,   -32,   -32,   -32,   -32,
      66,   -32,    71,   -32,   -32,    74,   -32,    65,    67,    68,
     -32,    76,   -32,   -32,   -32,   -32,   -32,   -32,   -32,    77,
      57,    58,   -32,   -32,   -32,    62,    70,   -32,   -32,   -32,
      54,    73,   -32
};

  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
     Performed when YYTABLE does not specify something else to do.  Zero
     means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     5,     0,     4,    21,    50,    22,    45,    51,
      23,    47,    25,    26,    27,    28,     0,     0,     0,     0,
       0,     0,    35,    36,    37,    38,     0,    24,    39,     1,
       3,     2,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     9,     0,     0,    29,    30,    31,    32,    33,    34,
       0,    48,    12,    41,    49,    13,    43,     0,     0,     0,
      20,    10,    19,    11,    17,     6,     8,    44,    46,     0,
       0,     0,    14,    15,    16,     0,     0,    40,    42,    18,
       0,     0,     7
};

  /* YYPGOTO[NTERM-NUM].  */
static const yytype_int8 yypgoto[] =
{
     -32,   -32,    86,   -32,   -32,    31,   -32,    13,    88,   -32,
     -32,   -32,   -32,    20,    23,    61,    69
};

  /* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int8 yydefgoto[] =
{
      -1,    21,    22,    23,    60,    61,    81,    82,    24,    72,
      75,    27,    30,    73,    76,    28,    31
};

  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
     positive, shift that token.  If negative, reduce the rule whose
     number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_uint8 yytable[] =
{
      49,    25,    26,    29,     1,     2,     3,     4,     5,     6,
       7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
      17,    18,    19,    32,    33,    34,    35,    36,    37,    38,
      39,    20,     1,     2,     3,     4,     5,     6,     7,     8,
       9,    10,    11,    12,    13,    14,    15,    16,    17,    18,
      19,    40,    41,    46,    52,    53,    42,    52,    53,    20,
      54,    55,    56,    54,    55,    56,    43,    44,    45,    47,
      62,    48,    57,    58,    64,    57,    58,    65,    63,    85,
      59,   101,    66,    59,    67,    70,    68,    69,    77,    71,
      74,    86,    78,    79,    80,    83,    90,    84,    89,    91,
      92,    95,   100,    93,    94,    96,   102,    50,    99,    51,
      97,     0,     0,     0,    98,     0,     0,     0,     0,     0,
       0,     0,     0,    87,     0,     0,     0,     0,     0,     0,
       0,     0,    88
};

static const yytype_int8 yycheck[] =
{
       0,    32,    32,    32,     4,     5,     6,     7,     8,     9,
      10,    11,    12,    13,    14,    15,    16,    17,    18,    19,
      20,    21,    22,    33,    33,    33,    33,    33,    33,    33,
      33,    31,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
      22,    33,    33,    32,     5,     6,    34,     5,     6,    31,
      11,    12,    13,    11,    12,    13,    34,    34,    34,    32,
      25,    33,    23,    24,    35,    23,    24,    36,    25,    30,
      31,    27,    36,    31,    36,    29,    36,    36,    33,    32,
      32,    60,    33,    33,    32,    32,    25,    33,    32,    25,
      35,    25,    32,    36,    36,    28,    33,    21,    95,    21,
      90,    -1,    -1,    -1,    91,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    62,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    63
};

  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
     symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,     4,     5,     6,     7,     8,     9,    10,    11,    12,
      13,    14,    15,    16,    17,    18,    19,    20,    21,    22,
      31,    38,    39,    40,    45,    32,    32,    48,    52,    32,
      49,    53,    33,    33,    33,    33,    33,    33,    33,    33,
      33,    33,    34,    34,    34,    34,    32,    32,    33,     0,
      39,    45,     5,     6,    11,    12,    13,    23,    24,    31,
      41,    42,    25,    25,    35,    36,    36,    36,    36,    36,
      29,    32,    46,    50,    32,    47,    51,    33,    33,    33,
      32,    43,    44,    32,    33,    30,    42,    52,    53,    32,
      25,    25,    35,    36,    36,    25,    28,    50,    51,    44,
      32,    27,    33
};

  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    37,    38,    38,    38,    38,    39,    40,    41,    41,
      42,    42,    42,    42,    42,    42,    42,    42,    43,    43,
      44,    45,    45,    45,    45,    45,    45,    45,    45,    45,
      45,    45,    45,    45,    45,    45,    45,    45,    45,    45,
      46,    46,    47,    47,    48,    48,    49,    49,    50,    51,
      52,    53
};

  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     2,     2,     1,     1,     3,     8,     2,     1,
       2,     2,     2,     2,     3,     3,     3,     2,     3,     1,
       1,     2,     2,     2,     2,     2,     2,     2,     2,     3,
       3,     3,     3,     3,     3,     2,     2,     2,     2,     2,
       3,     1,     3,     1,     3,     1,     3,     1,     1,     1,
       1,     1
};


#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)
#define YYEMPTY         (-2)
#define YYEOF           0

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (yyscanner, coll, YY_("syntax error: cannot back up")); \
      YYERROR;                                                  \
    }                                                           \
while (0)

/* Error token number */
#define YYTERROR        1
#define YYERRCODE       256



/* Enable debugging if requested.  */
#if CONF_DEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)

/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


# define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Type, Value, yyscanner, coll); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*----------------------------------------.
| Print this symbol's value on YYOUTPUT.  |
`----------------------------------------*/

static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll)
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  YYUSE (yyscanner);
  YYUSE (coll);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll)
{
  YYFPRINTF (yyoutput, "%s %s (",
             yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yyscanner, coll);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yyscanner, Collection* coll)
{
  unsigned long int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       yystos[yyssp[yyi + 1 - yynrhs]],
                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                              , yyscanner, coll);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule, yyscanner, coll); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !CONF_DEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !CONF_DEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
yystrlen (const char *yystr)
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            /* Fall through.  */
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner, Collection* coll)
{
  YYUSE (yyvaluep);
  YYUSE (yyscanner);
  YYUSE (coll);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YYUSE (yytype);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}




/*----------.
| yyparse.  |
`----------*/

int
yyparse (yyscan_t yyscanner, Collection* coll)
{
/* The lookahead symbol.  */
int yychar;


/* The semantic value of the lookahead symbol.  */
/* Default value used for initialization, for pacifying older GCCs
   or non-GCC compilers.  */
YY_INITIAL_VALUE (static YYSTYPE yyval_default;)
YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);

    /* Number of syntax errors so far.  */
    int yynerrs;

    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       'yyss': related to states.
       'yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        YYSTYPE *yyvs1 = yyvs;
        yytype_int16 *yyss1 = yyss;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * sizeof (*yyssp),
                    &yyvs1, yysize * sizeof (*yyvsp),
                    &yystacksize);

        yyss = yyss1;
        yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yytype_int16 *yyss1 = yyss;
        union yyalloc *yyptr =
          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
        if (! yyptr)
          goto yyexhaustedlab;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yylex (&yylval, yyscanner);
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 6:
#line 137 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, 
	    "collectionStanza: newCollection collectionLines confENDBLOCK");
  coll = 0;
}
#line 1429 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 7:
#line 145 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, 
	    "newCollection: confCOLL confSTRING confAROBASE confSTRING"
	    " confCOLON confNUMBER");
  if (!(coll = addCollection((yyvsp[-4].string)))) YYERROR;

  if (!(coll->masterLabel = createString((yyvsp[-6].string)))) YYERROR;
  strncpy(coll->masterHost, (yyvsp[-2].string), MAX_SIZE_HOST);
  coll->masterPort = (yyvsp[0].number);
}
#line 1444 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 11:
#line 163 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i localhost = %s", LINENO, (yyvsp[0].string));
  strncpy(coll->userFingerPrint, (yyvsp[0].string), MAX_SIZE_MD5+1);
}
#line 1453 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 14:
#line 170 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache size");
  coll->cacheSize = (yyvsp[-1].number)*(yyvsp[0].size);
}
#line 1462 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 15:
#line 175 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache TTL");
  coll->cacheTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1471 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 16:
#line 180 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "query TTL");
  coll->queryTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1480 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 17:
#line 185 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "motd policy");
  coll->motdPolicy = (yyvsp[0].number);
}
#line 1489 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 20:
#line 196 "parser/confFile.y" /* yacc.c:1646  */
    {
  Support* supp = 0;
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "support");
  if (!(supp = addSupport((yyvsp[0].string)))) YYERROR;
  if (!addSupportToCollection(supp, coll)) YYERROR;
}
#line 1500 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 21:
#line 205 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i host = %s", LINENO, (yyvsp[0].string));
  strncpy(getConfiguration()->host, (yyvsp[0].string), MAX_SIZE_HOST);
}
#line 1509 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 22:
#line 210 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i networks", LINENO);
}
#line 1517 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 23:
#line 214 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i gateways", LINENO);
}
#line 1525 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 24:
#line 218 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i comment = %s", LINENO, (yyvsp[0].string));
  destroyString(getConfiguration()->comment);
  if (!(getConfiguration()->comment = createString((yyvsp[0].string)))) YYERROR;
}
#line 1535 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 25:
#line 224 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i mdtxPort = %i", LINENO, (yyvsp[0].number));
  getConfiguration()->mdtxPort = (yyvsp[0].number);
}
#line 1544 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 26:
#line 229 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i sshPort = %i", LINENO, (yyvsp[0].number));
  getConfiguration()->sshPort = (yyvsp[0].number);
}
#line 1553 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 27:
#line 234 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i httpPort = %i", LINENO, (yyvsp[0].number));
  getConfiguration()->httpPort = (yyvsp[0].number);
}
#line 1562 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 28:
#line 239 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i httpsPort = %i", LINENO, (yyvsp[0].number));
  getConfiguration()->httpsPort = (yyvsp[0].number);
}
#line 1571 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 29:
#line 244 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache size");
  getConfiguration()->cacheSize = (yyvsp[-1].number)*(yyvsp[0].size);
}
#line 1580 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 30:
#line 249 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "cache TTL");
  getConfiguration()->cacheTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1589 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 31:
#line 254 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "query TTL");
  getConfiguration()->queryTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1598 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 32:
#line 259 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "check TTL");
  getConfiguration()->checkTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1607 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 33:
#line 264 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "check TTL");
  getConfiguration()->fileTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1616 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 34:
#line 269 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "supp TTL");
  getConfiguration()->scoreParam.suppTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1625 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 35:
#line 274 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: max");
  getConfiguration()->scoreParam.maxScore = (yyvsp[0].score);
}
#line 1634 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 36:
#line 279 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: bad");
  getConfiguration()->scoreParam.badScore = (yyvsp[0].score);
}
#line 1643 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 37:
#line 284 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: pow supp");
  getConfiguration()->scoreParam.powSupp = (yyvsp[0].score);
}
#line 1652 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 38:
#line 289 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "score: fact supp");
  getConfiguration()->scoreParam.factSupp = (yyvsp[0].score);
}
#line 1661 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 39:
#line 294 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i %s", LINENO, "motd policy");
  getConfiguration()->motdPolicy = (yyvsp[0].number);
}
#line 1670 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 48:
#line 318 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i network: %s", LINENO, (yyvsp[0].string));
  if (!addNetworkToRing(coll->networks, (yyvsp[0].string))) YYABORT;
}
#line 1679 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 49:
#line 325 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i gateway: %s", LINENO, (yyvsp[0].string));
  if (!addNetworkToRing(coll->gateways, (yyvsp[0].string))) YYABORT;
}
#line 1688 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 50:
#line 332 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i network: %s", LINENO, (yyvsp[0].string));
  if (!addNetworkToRing(getConfiguration()->networks, (yyvsp[0].string))) YYABORT;
}
#line 1697 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;

  case 51:
#line 339 "parser/confFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i gateway: %s", LINENO, (yyvsp[0].string));
  if (!addNetworkToRing(getConfiguration()->gateways, (yyvsp[0].string))) YYABORT;
}
#line 1706 "parser/confFile.tab.c" /* yacc.c:1646  */
    break;


#line 1710 "parser/confFile.tab.c" /* yacc.c:1646  */
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (yyscanner, coll, YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yyscanner, coll, yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval, yyscanner, coll);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYTERROR;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  yystos[yystate], yyvsp, yyscanner, coll);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (yyscanner, coll, YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval, yyscanner, coll);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  yystos[*yyssp], yyvsp, yyscanner, coll);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  return yyresult;
}
#line 345 "parser/confFile.y" /* yacc.c:1906  */

	  /* epilogue: =================================================*/


/*=======================================================================
 * Function   : parsererror
 * Description: Emit an error message. Called by the parser on error
 *              state.
 * Synopsis   : void parsererror(char* message)
 * Input      : char* message = the error message.
 * Output     : N/A
 * Note       : Sorry, find no way to get the lineNo using reentrant
 *              parser.
 =======================================================================*/
void 
conf_error(yyscan_t yyscanner, Collection* coll, const char* message)
{
  logParser(LOG_ERR, "%s on token '%s' line %i", message, 
	  conf_get_text(yyscanner), LINENO);
}

/*=======================================================================
 * Function   : parseConfiguration
 * Description: Parse a file
 * Synopsis   : int parseConfiguration(const char* path)
 * Input      : const char* path: the file to parse
 * Output     : TRUE on success
=======================================================================*/
int 
parseConfiguration(const char* path)
{ 
  int rc = FALSE;
  FILE* inputStream = stdin;
  yyscan_t scanner;
  Collection* coll = 0;
 
  logParser(LOG_INFO, "parse configuration from %s",
	    path?path:"stdin");

  // initialise scanner
  if (conf_lex_init(&scanner)) {
    logParser(LOG_ERR, "%s", "error initializing scanner");
    goto error;
  }

  if (path != 0) {
    if ((inputStream = fopen(path, "r")) == 0) {
      logParser(LOG_ERR, "cannot open input stream: %s", path); 
      goto error;
    }
  }

  conf_set_in(inputStream, scanner);

  // debug mode for scanner
  conf_set_debug(env.debugLexer, scanner);
  logParser(LOG_DEBUG, "conf_set_debug = %i", conf_get_debug(scanner));

  // call the parser
  if (conf_parse(scanner, coll)) {
    logParser(LOG_ERR, "configuration parser fails on line %i", 
	    conf_get_lineno(scanner));
    logParser(LOG_ERR, "please edit %s", path?path:"stdin");
    goto error2;
  }

  rc = TRUE;
 error2:
  if (inputStream != stdin) {
    fclose(inputStream);
  }
 error:
  if (!rc) {
    logParser(LOG_ERR, "%s", "configuration parser fails");
  }
  conf_lex_destroy(scanner);
  return rc;
}

/* Local Variables: */
/* mode: c */
/* mode: font-lock */
/* mode: auto-fill */
/* End: */

